// BLETest

#include <ArduinoBLE.h>

#define BLE_SERVICE_UUID "fff0"
#define BLE_CHARACTERISTIC_UUID "fff1"

BLEService miniService(BLE_SERVICE_UUID); 
BLEByteCharacteristic miniControlCharacteristic(BLE_CHARACTERISTIC_UUID, BLEWrite | BLERead | BLENotify); // fixed

// -------------------------------------------------------------------------- 
void setup() {
  Serial.begin(115200);
  while(! Serial) delay(5); 
  Serial.println("BLE Test");

  pinMode(LED_BUILTIN, OUTPUT);
  
  if(!BLE.begin()) {
    Serial.println("starting Bluetooth® Low Energy module failed!");
    while (1);
  }

  BLE.setLocalName("Nano BLE");
  BLE.setAdvertisedService(miniService);
  miniService.addCharacteristic(miniControlCharacteristic);  // add the characteristics to the service
  BLE.addService(miniService);  // add the service
  miniControlCharacteristic.writeValue((byte)0x00);
  BLE.advertise();  // start advertising
  Serial.println("Bluetooth® Low Energy device active, waiting for connections...");
}

// -------------------------------------------------------------------------- 
void loop() {
  uint8_t AppCmd;

  BLEDevice controller = BLE.central();  // listen for BLE peripherals to connect:

  if (controller) {
    Serial.print("Connected to controller: ");
    Serial.println(controller.address());   
        
    // while the controller is still connected to peripheral:
    while (controller.connected()) {
      if (miniControlCharacteristic.written()) {        
        miniControlCharacteristic.readValue(AppCmd);

        if(AppCmd > 0) {
          Serial.println("characteristic written");
          
          switch (AppCmd) {
            case 1:
              Serial.println("Button 1"); 
              digitalWrite(LED_BUILTIN, HIGH);           
              break;
            case 2:
              Serial.println("Button 2");
              digitalWrite(LED_BUILTIN, LOW);
              miniControlCharacteristic.writeValue((byte)0x03);             
              break;
            
            default:
              Serial.println("STOP");            
              break;
          }
        }
      }  
    }

    // when the central disconnects, print it out:
    Serial.print(F("Disconnected from controller: "));
    Serial.println(controller.address());
    digitalWrite(LED_BUILTIN, LOW); 
  }
}